imblearn.combine.SMOTEENN
=========================

.. currentmodule:: imblearn.combine

.. autoclass:: SMOTEENN

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~SMOTEENN.__init__
      ~SMOTEENN.fit
      ~SMOTEENN.fit_sample
      ~SMOTEENN.get_params
      ~SMOTEENN.sample
      ~SMOTEENN.set_params
   
   

   
   
   